
<!--
FrozenIsBool False
-->

#Rower

##Doc
----


> 
> The Rower helps to set rowed lines in a Databaser from pointed attributes,
> ready then to be inserted in a table.
> 
> 

----

<small>
View the Rower notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Rower.ipynb)
</small>

